.. mylib documentation master file, created by
   sphinx-quickstart on Wed Nov  9 22:22:34 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mylib's documentation!
=================================

**mylib** is python library that hosts image processing and data analysis tools I developed to facilitate my PhD and postdoc research. Tools include particle tracking, PIV, file batch reading, spatiotemporal correlation analysis, etc.

.. note::

  This documentation is under active development.

Contents
--------

.. toctree::

  usage
  myImageLib
  corrLib
  pivLib
